export declare function formatDate(date: Date, showTwelveHour?: boolean): string;
export declare function formatFullDateNoTime(date: Date): string;
export declare function formatFullDate(date: Date, showTwelveHour?: boolean, showSeconds?: boolean): string;
/**
 * Formats dates to be compatible with attributes of a `<input type="date">`. Dates
 * should be formatted like "2020-06-23" (formatted according to ISO8601)
 *
 * @param date The date to format.
 * @returns The date string in ISO8601 format ready to be used with an `<input>`
 */
export declare function formatDateForInput(date: Date): string;
export declare function formatFullTime(date: Date, showTwelveHour?: boolean): string;
export declare function formatTime(date: Date, showTwelveHour?: boolean): string;
export declare function formatSeconds(inSeconds: number): string;
export declare function formatTimeLeft(inSeconds: number): string;
export declare function wantsDateSeparator(prevEventDate: Date | null | undefined, nextEventDate: Date | null | undefined): boolean;
export declare function formatFullDateNoDay(date: Date): string;
/**
 * Returns an ISO date string without textual description of the date (ie: no "Wednesday" or
 * similar)
 * @param date The date to format.
 * @returns The date string in ISO format.
 */
export declare function formatFullDateNoDayISO(date: Date): string;
export declare function formatFullDateNoDayNoTime(date: Date): string;
export declare function formatRelativeTime(date: Date, showTwelveHour?: boolean): string;
/**
 * Formats duration in ms to human readable string
 * Returns value in biggest possible unit (day, hour, min, second)
 * Rounds values up until unit threshold
 * ie. 23:13:57 -> 23h, 24:13:57 -> 1d, 44:56:56 -> 2d
 */
export declare function formatDuration(durationMs: number): string;
/**
 * Formats duration in ms to human readable string
 * Returns precise value down to the nearest second
 * ie. 23:13:57 -> 23h 13m 57s, 44:56:56 -> 1d 20h 56m 56s
 */
export declare function formatPreciseDuration(durationMs: number): string;
/**
 * Formats a timestamp to a short date
 * (eg 25/12/22 in uk locale)
 * localised by system locale
 * @param timestamp - epoch timestamp
 * @returns {string} formattedDate
 */
export declare const formatLocalDateShort: (timestamp: number) => string;
