import React from "react";
import { TypedEventEmitter } from "matrix-js-sdk/src/models/typed-event-emitter";
export type ComponentType = React.ComponentType<{
    onFinished?(...args: any): void;
}>;
type Defaultize<P, D> = P extends any ? string extends keyof P ? P : Pick<P, Exclude<keyof P, keyof D>> & Partial<Pick<P, Extract<keyof P, keyof D>>> & Partial<Pick<D, Exclude<keyof D, keyof P>>> : never;
export type ComponentProps<C extends ComponentType> = Defaultize<Omit<React.ComponentProps<C>, "onFinished">, C["defaultProps"]> & Partial<Pick<React.ComponentProps<C>, "onFinished">>;
export interface IModal<C extends ComponentType> {
    elem: React.ReactNode;
    className?: string;
    beforeClosePromise?: Promise<boolean>;
    closeReason?: string;
    onBeforeClose?(reason?: string): Promise<boolean>;
    onFinished: ComponentProps<C>["onFinished"];
    close(...args: Parameters<ComponentProps<C>["onFinished"]>): void;
    hidden?: boolean;
}
export interface IHandle<C extends ComponentType> {
    finished: Promise<Parameters<ComponentProps<C>["onFinished"]>>;
    close(...args: Parameters<ComponentProps<C>["onFinished"]>): void;
}
interface IOptions<C extends ComponentType> {
    onBeforeClose?: IModal<C>["onBeforeClose"];
}
export declare enum ModalManagerEvent {
    Opened = "opened"
}
type HandlerMap = {
    [ModalManagerEvent.Opened]: () => void;
};
export declare class ModalManager extends TypedEventEmitter<ModalManagerEvent, HandlerMap> {
    private counter;
    private priorityModal;
    private staticModal;
    private modals;
    private static getOrCreateContainer;
    private static getOrCreateStaticContainer;
    toggleCurrentDialogVisibility(): void;
    hasDialogs(): boolean;
    createDialog<C extends ComponentType>(Element: C, props?: ComponentProps<C>, className?: string, isPriorityModal?: boolean, isStaticModal?: boolean, options?: IOptions<C>): IHandle<C>;
    appendDialog<C extends ComponentType>(Element: React.ComponentType, props?: ComponentProps<C>, className?: string): IHandle<C>;
    /**
     * @param reason either "backgroundClick" or undefined
     * @return whether a modal was closed
     */
    closeCurrentModal(reason?: string): boolean;
    private buildModal;
    private getCloseFn;
    /**
     * @callback onBeforeClose
     * @param {string?} reason either "backgroundClick" or null
     * @return {Promise<bool>} whether the dialog should close
     */
    /**
     * Open a modal view.
     *
     * This can be used to display a react component which is loaded as an asynchronous
     * webpack component. To do this, set 'loader' as:
     *
     *   (cb) => {
     *       require(['<module>'], cb);
     *   }
     *
     * @param {Promise} prom   a promise which resolves with a React component
     *   which will be displayed as the modal view.
     *
     * @param {Object} props   properties to pass to the displayed
     *    component. (We will also pass an 'onFinished' property.)
     *
     * @param {String} className   CSS class to apply to the modal wrapper
     *
     * @param {boolean} isPriorityModal if true, this modal will be displayed regardless
     *                                  of other modals that are currently in the stack.
     *                                  Also, when closed, all modals will be removed
     *                                  from the stack.
     * @param {boolean} isStaticModal  if true, this modal will be displayed under other
     *                                 modals in the stack. When closed, all modals will
     *                                 also be removed from the stack. This is not compatible
     *                                 with being a priority modal. Only one modal can be
     *                                 static at a time.
     * @param {Object} options? extra options for the dialog
     * @param {onBeforeClose} options.onBeforeClose a callback to decide whether to close the dialog
     * @returns {object} Object with 'close' parameter being a function that will close the dialog
     */
    createDialogAsync<C extends ComponentType>(prom: Promise<C>, props?: ComponentProps<C>, className?: string, isPriorityModal?: boolean, isStaticModal?: boolean, options?: IOptions<C>): IHandle<C>;
    private appendDialogAsync;
    private emitIfChanged;
    private onBackgroundClick;
    private getCurrentModal;
    private reRender;
}
declare const _default: ModalManager;
export default _default;
