import React, { ReactNode } from "react";
import { MatrixClient } from "matrix-js-sdk/src/client";
import { RoomMember } from "matrix-js-sdk/src/models/room-member";
import { User } from "matrix-js-sdk/src/models/user";
import { Room } from "matrix-js-sdk/src/models/room";
import { VerificationRequest } from "matrix-js-sdk/src/crypto/verification/request/VerificationRequest";
import { DeviceInfo } from "matrix-js-sdk/src/crypto/deviceinfo";
import { RightPanelPhases } from "../../../stores/right-panel/RightPanelStorePhases";
import { E2EStatus } from "../../../utils/ShieldUtils";
export interface IDevice extends DeviceInfo {
    ambiguous?: boolean;
}
export declare const disambiguateDevices: (devices: IDevice[]) => void;
export declare const getE2EStatus: (cli: MatrixClient, userId: string, devices: IDevice[]) => E2EStatus;
export declare function DeviceItem({ userId, device }: {
    userId: string;
    device: IDevice;
}): JSX.Element;
export declare const UserOptionsSection: React.FC<{
    member: Member;
    isIgnored: boolean;
    canInvite: boolean;
    isSpace?: boolean;
}>;
interface IPowerLevelsContent {
    events?: Record<string, number>;
    users_default?: number;
    events_default?: number;
    state_default?: number;
    ban?: number;
    kick?: number;
    redact?: number;
}
export declare const isMuted: (member: RoomMember, powerLevelContent: IPowerLevelsContent) => boolean;
export declare const getPowerLevels: (room: Room) => IPowerLevelsContent;
export declare const useRoomPowerLevels: (cli: MatrixClient, room: Room) => IPowerLevelsContent;
interface IBaseProps {
    member: RoomMember;
    startUpdating(): void;
    stopUpdating(): void;
}
export declare const RoomKickButton: ({ room, member, startUpdating, stopUpdating, }: Omit<IBaseRoomProps, "powerLevels">) => JSX.Element | null;
export declare const BanToggleButton: ({ room, member, startUpdating, stopUpdating, }: Omit<IBaseRoomProps, "powerLevels">) => JSX.Element;
interface IBaseRoomProps extends IBaseProps {
    room: Room;
    powerLevels: IPowerLevelsContent;
    children?: ReactNode;
}
export declare const RoomAdminToolsContainer: React.FC<IBaseRoomProps>;
interface IRoomPermissions {
    modifyLevelMax: number;
    canEdit: boolean;
    canInvite: boolean;
}
export declare const PowerLevelEditor: React.FC<{
    user: RoomMember;
    room: Room;
    roomPermissions: IRoomPermissions;
}>;
export declare const useDevices: (userId: string) => IDevice[] | undefined | null;
export type Member = User | RoomMember;
export declare const UserInfoHeader: React.FC<{
    member: Member;
    e2eStatus?: E2EStatus;
    roomId?: string;
}>;
interface IProps {
    user: Member;
    room?: Room;
    phase: RightPanelPhases.RoomMemberInfo | RightPanelPhases.SpaceMemberInfo | RightPanelPhases.EncryptionPanel;
    onClose(): void;
    verificationRequest?: VerificationRequest;
    verificationRequestPromise?: Promise<VerificationRequest>;
}
declare const UserInfo: React.FC<IProps>;
export default UserInfo;
